rm(list=ls(all=TRUE))

setwd("files")

# Script 1
print(file_contents <- readLines("text_1.txt"))



# Script 2
get_file_contents <- function (file_path) { # define a function get_file_contents, which takes a path as an argument
   file_contents <- readLines("text_1.txt") # read the file into file_contents
   print(file_contents) # print the file contents
} # end of function definition
get_file_contents("text_1.txt")



# Script 3
library(rvest) # either using the package rvest
file_contents <- read_html("html_example.txt") # load the HTML file and
html_text(file_contents)                       # ... output it to screen

library(XML) # or using the package XML
file_contents <- readLines("html_example.txt") # read the file into file_contents and
file_contents <- xmlParse(file_contents)       # ... parse its html/xml structure
xpathSApply(file_contents, "//h1", xmlValue) # header level 1
xpathSApply(file_contents, "//p", xmlValue)  # the paragraph
# xpathSApply(file_contents, "//text()[not(ancestor::script)][not(ancestor::style)][not(ancestor::noscript)][not(ancestor::form)]", xmlValue)

library(xml2) # or using the package xml2
file_contents <- read_xml("html_example.txt") # read/parse the file into file_contents
xml_text(file_contents)
as.character(xml_find_all(file_contents, "//h1")) # header level 1
as.character(xml_find_all(file_contents, "//p"))  # the paragraph



# Script 4
library(rvest) # using the package rvest and regexes
file_contents <- read_html("http://www.python.org/") # read the file into file_contents
text_on_page <- html_text(file_contents) # parse its html structure
text_on_page <- gsub("<.*?>", "", text_on_page, perl=TRUE)# delete tags
text_on_page <- unlist(strsplit(text_on_page, "\n+", perl=TRUE)) # split on line breaks
grep("[^ ]", text_on_page, perl=TRUE, value=TRUE) # discard empty lines



# Script 5
script5 <- function (location) { # define a function that takes a folder/location as argument
   corpus_files <- dir(location, full.names=TRUE) # find all the files in that folder/location
   for (each_file in corpus_files) { # for each file in that folder
      cat(scan(each_file, what=character(), sep="\n", quiet=TRUE), sep="\n") # load the file and print it line by line
   } # end of for-loop
} # end of function definition
script5("targetcorpus") # run the function



# Script 6
corpus_paths <- dir("targetcorpus", full.names=TRUE) # create vector with file paths
frequencies <- c()                                   # create vector for frequencies
for (each_path in corpus_paths) { # loop through paths
   file_contents <- tolower(readLines(each_path)) # read each file and change to lower case
   words <- unlist(strsplit(file_contents, "[^\\p{L}]+", perl=TRUE)) # identify the words and
   frequencies <- c(frequencies, table(words))                       # ... collect their frequencies
   frequencies <- tapply(frequencies, names(frequencies), sum) # ... aggregate with those from previous files
}
print(frequencies) # show the output



# Script 7
corpus_paths <- dir("targetcorpus", full.names=TRUE) # create vector with file paths
search_term <- "[\\p{L}]+at\\b"                      # create search term
matches <- c()                                       # create vector for matches
for (each_path in corpus_paths) { # loop through paths
   file_contents <- tolower(readLines(each_path)) # read each file and change to lower case
   file_contents <- grep(search_term, file_contents, perl=TRUE, value=TRUE) # find the lines with the term
   mat <- gregexpr(search_term, file_contents, perl=TRUE) # find the positions of the term
   file_contents <- rep(file_contents, sapply(mat, length)) # repeat each line as often as it has matches
   starts <- unlist(mat)                                         # find start positions of smatches
   stops <- starts + unlist(sapply(mat, attr, "match.length"))-1 # find end positions of matches
   # stops <- (starts <- unlist(mat)) + unlist(sapply(mat, attr, "match.length"))-1
   matches <- c(matches,                                    # collect with previous matches
                paste(substr(file_contents, 1, starts-1),   # the combination of what's before the current ones
                      substr(file_contents, starts, stops), # the current matches and
                      substr(file_contents, stops+1, nchar(file_contents)), sep="\t")) # ... what's after them
}
cat(matches, sep="\n", file="kwic_results.txt") # output

# this can be simplified drastically with Gries's (2016) function exact.matches.2. With it, the above would reduce to:
corpus_paths <- dir("targetcorpus", full.names=TRUE) # create vector with file paths
search_term <- "[\\p{L}]+at\\b" # create search term
matches <- c() # create vector for matches
for (each_path in corpus_paths) { # loop through paths
   file_contents <- tolower(readLines(each_path)) # read each file and change to lower case
   matches <- c(matches, exact.matches.2(search_term, file_contents)[[4]]) # add new matches to old ones
}
cat(matches, sep="\n", file="kwic_results.txt") # save the output
